<?php
/**
 * Theme functions and definitions
 *
 * @package organic_grocery
 */ 

if ( ! function_exists( 'organic_grocery_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function organic_grocery_enqueue_styles() {
		wp_enqueue_style( 'organic-farm-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'organic-grocery-style', get_stylesheet_directory_uri() . '/style.css', array( 'organic-farm-style-parent' ), '1.0.0' );
		// Theme Customize CSS.
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'organic-grocery-style',$organic_farm_custom_style );
	}
endif;
add_action( 'wp_enqueue_scripts', 'organic_grocery_enqueue_styles', 99 );

function organic_grocery_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'organic-grocery-featured-image', 2000, 1200, true );
	add_image_size( 'organic-grocery-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'organic-grocery' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css', organic_farm_fonts_url() ) );
}
add_action( 'after_setup_theme', 'organic_grocery_setup' );

function organic_grocery_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'organic-grocery' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'organic-grocery' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'organic-grocery' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'organic-grocery' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'organic-grocery' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'organic-grocery' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Product Category Dropdown', 'organic-grocery' ),
		'id'            => 'product-cat',
		'description'   => __( 'Add widgets here to appear in your header.', 'organic-grocery' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'organic_grocery_widgets_init' );

function organic_grocery_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'organic_farm_pro' );
}
add_action( 'customize_register', 'organic_grocery_customize_register', 11 );

function organic_grocery_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	$wp_customize->add_section('organic_grocery_pro', array(
		'title'    => __('UPGRADE GROCERY PREMIUM', 'organic-grocery'),
		'priority' => 1,
	));

	$wp_customize->add_setting('organic_grocery_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new Organic_Grocery_Pro_Control($wp_customize, 'organic_grocery_pro', array(
		'label'    => __('GROCERY PREMIUM', 'organic-grocery'),
		'section'  => 'organic_grocery_pro',
		'settings' => 'organic_grocery_pro',
		'priority' => 1,
	)));  

	//Category Section
	$wp_customize->add_section('organic_grocery_category_section',array(
		'title'	=> __('Category Section','organic-grocery'),
		'description'=> __('This section will appear below the category.','organic-grocery'),
	));

    $wp_customize->add_setting('organic_grocery_grocery_cate_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('organic_grocery_grocery_cate_title',array(
		'label'	=> __('Section Title','organic-grocery'),
		'section' => 'organic_grocery_category_section',
		'type' => 'text'
	));

	$wp_customize->add_setting('organic_grocery_category_number',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('organic_grocery_category_number',array(
		'label'	=> __('Number of posts to show in a category','organic-grocery'),
		'section' => 'organic_grocery_category_section',
		'type'	  => 'number'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('organic_grocery_category_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'organic_farm_sanitize_choices',
	));
	$wp_customize->add_control('organic_grocery_category_setting',array(
		'type' => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','organic-grocery'),
		'section' => 'organic_grocery_category_section',
	));

	$organic_grocery_category_number = get_theme_mod('organic_grocery_category_number','');
	for ($i=1; $i <= $organic_grocery_category_number; $i++) { 
	    $wp_customize->add_setting('organic_grocery_category_icon'.$i,array(
			'default' => '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));	
		$wp_customize->add_control('organic_grocery_category_icon'.$i,array(
			'label'	=> __('Category Icon ','organic-grocery').$i,
			'description' => __('Fontawesome Icon Class Ex: fas fa-apple-alt','organic-grocery'),
			'section' => 'organic_grocery_category_section',
			'type' => 'text'
		));
	}
}
add_action( 'customize_register', 'organic_grocery_customize' );

function organic_grocery_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action(  'wp_enqueue_scripts', 'organic_grocery_enqueue_comments_reply' );

if ( ! defined( 'ORGANIC_GROCERY_PRO_LINK' ) ) {
	define('ORGANIC_GROCERY_PRO_LINK',__('https://www.ovationthemes.com/wordpress/organic-grocery-wordpress-theme/','organic-grocery'));
}

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Organic_Grocery_Pro_Control')):
    class Organic_Grocery_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( ORGANIC_GROCERY_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE GROCERY PREMIUM','organic-grocery');?> </a>
            </div>
            <div class="col-md">
                <img class="organic_grocery_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('GROCERY PREMIUM - Features', 'organic-grocery'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'organic-grocery');?> </li>
                    <li class="upsell-organic_grocery"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'organic-grocery');?> </li>                    
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( ORGANIC_GROCERY_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE GROCERY PREMIUM','organic-grocery');?> </a>
            </div>            
        </label>
    <?php } }
endif;

if ( ! defined( 'ORGANIC_FARM_SUPPORT' ) ) {
	define('ORGANIC_FARM_SUPPORT',__('https://wordpress.org/support/theme/organic-grocery','organic-grocery'));
}
if ( ! defined( 'ORGANIC_FARM_REVIEW' ) ) {
	define('ORGANIC_FARM_REVIEW',__('https://wordpress.org/support/theme/organic-grocery/reviews/#new-post','organic-grocery'));
}
if ( ! defined( 'ORGANIC_FARM_LIVE_DEMO' ) ) {
define('ORGANIC_FARM_LIVE_DEMO',__('https://www.ovationthemes.com/demos/organic-grocery/','organic-grocery'));
}
if ( ! defined( 'ORGANIC_FARM_BUY_PRO' ) ) {
define('ORGANIC_FARM_BUY_PRO',__('https://www.ovationthemes.com/wordpress/organic-grocery-wordpress-theme/','organic-grocery'));
}
if ( ! defined( 'ORGANIC_FARM_PRO_DOC' ) ) {
define('ORGANIC_FARM_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-organic-grocery-pro-doc/','organic-grocery'));
}
if ( ! defined( 'ORGANIC_FARM_THEME_NAME' ) ) {
define('ORGANIC_FARM_THEME_NAME',__('Premium Grocery Theme','organic-grocery'));
}